Rcmdr menu interface to plot the qqplot of variable against one of the following distributions: normal, t, chi-square, F, other.
Usage
QQPlot.HH()
Arguments
Value
NULL. These functions are used only for their side effect (to
make a graph).
Details
The normal gives the option to do the Shapiro-Wilk test of normality.
The other requires you to specify the distribution.
Any distribution for which quantile and density functions exist in
R (with prefixes q and d, respectively) may be used.